@@ -942,7 +942,7 @@ namespace lsp
                 for (size_t j=0; j<nFilters; ++j)
                 {
                     eq_filter_t *f  = &c->vFilters[j];
-                    dsp::complex_mul3(c->vTrRe, c->vTrIm, c->vTrRe, c->vTrIm, f->vTrRe, f->vTrIm, para_equalizer_base_metadata::MESH_POINTS);
+                    dsp::complex_mul2(c->vTrRe, c->vTrIm, f->vTrRe, f->vTrIm, para_equalizer_base_metadata::MESH_POINTS);
                 }
                 c->nSync    = CS_SYNC_AMP;
             }
